@@ -9,9 +9,12 @@ assert len(argv) == 2, 'Must provide: name, path'
 name, path = argv
 
 
-template = f'''lint:
+template = '''lint:
 	flake8 --select=C,F,E101,E112,E502,E72,E73,E74,E9,W291,W6 --exclude=.cache,migrations
 
+clean:
+	find -depth -name '__pycache__' -exec rm -rfv '{}' ';'
+
 
 docker:
 	# TODO: update tag
